# Installation

## Using pip

```console
pip install xsdata-attrs[cli,lxml,soap]
```

!!! hint

    - Install the cli requirements for the code generator
    - Install the soap requirements for the builtin wsdl client
    - Install lxml for enhanced performance and advanced features

## From repository

```console
pip install xsdata[cli,lxml] @ git+https://github.com/tefra/xsdata-attrs
```

## Using conda

```console
conda install -c conda-forge xsdata-attrs
```
